aboutsummaryrefslogtreecommitdiffstats
path: root/packages/meshbay-hub/src/meshbay_hub/static/app.js
diff options
context:
space:
mode:
Diffstat (limited to 'packages/meshbay-hub/src/meshbay_hub/static/app.js')
-rw-r--r--packages/meshbay-hub/src/meshbay_hub/static/app.js6
1 files changed, 4 insertions, 2 deletions
diff --git a/packages/meshbay-hub/src/meshbay_hub/static/app.js b/packages/meshbay-hub/src/meshbay_hub/static/app.js
index d8818d0..579d1dd 100644
--- a/packages/meshbay-hub/src/meshbay_hub/static/app.js
+++ b/packages/meshbay-hub/src/meshbay_hub/static/app.js
@@ -948,9 +948,11 @@ function App() {
return () => { gone = true; if (stop) stop(); };
}, [syncAccount]);
// Files backup (§9.13), the same way.
useEffect(() => {
- if (!syncAccount || !platform.driveSync.available) return undefined;
+ if (!syncAccount || !(platform.driveSync.available || platform.whatsappSync.available)) {
+ return undefined;
+ }
let stop = null;
let gone = false;
import('./drive-sync.js').then((m) => {
@@ -948,9 +948,11 @@ function App() {
return () => { gone = true; if (stop) stop(); };
}, [syncAccount]);
- // Files backup (§9.13), the same way.
+ // Files and WhatsApp backups (§9.13), the same way.
useEffect(() => {